
# Type: anatomical entity to anatomical entity ontogenic association_relation




URI: [biolink:anatomical_entity_to_anatomical_entity_ontogenic_association_relation](https://w3id.org/biolink/vocab/anatomical_entity_to_anatomical_entity_ontogenic_association_relation)


## Domain and Range

[AnatomicalEntityToAnatomicalEntityOntogenicAssociation](AnatomicalEntityToAnatomicalEntityOntogenicAssociation.md) ->  <sub>REQ</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents

 *  is_a: [relation](relation.md)

## Children


## Used by

 * [AnatomicalEntityToAnatomicalEntityOntogenicAssociation](AnatomicalEntityToAnatomicalEntityOntogenicAssociation.md)
